Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(217)

Unified Diff: net/http/http_stream_parser.h

Issue 8990001: base::Bind: Convert most of net/http. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Clang. Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_stream_parser.h
diff --git a/net/http/http_stream_parser.h b/net/http/http_stream_parser.h
index b80145f4f48e1b64eaeda09541511932b8927d6a..ae9fc3e3ed5cfcb151ec3525a4b6da2b5a367298 100644
--- a/net/http/http_stream_parser.h
+++ b/net/http/http_stream_parser.h
@@ -44,12 +44,13 @@ class HttpStreamParser : public ChunkCallback {
int SendRequest(const std::string& request_line,
const HttpRequestHeaders& headers,
UploadDataStream* request_body,
- HttpResponseInfo* response, OldCompletionCallback* callback);
+ HttpResponseInfo* response,
+ const CompletionCallback& callback);
- int ReadResponseHeaders(OldCompletionCallback* callback);
+ int ReadResponseHeaders(const CompletionCallback& callback);
int ReadResponseBody(IOBuffer* buf, int buf_len,
- OldCompletionCallback* callback);
+ const CompletionCallback& callback);
void Close(bool not_reusable);
@@ -175,13 +176,13 @@ class HttpStreamParser : public ChunkCallback {
// The callback to notify a user that their request or response is
// complete or there was an error
- OldCompletionCallback* user_callback_;
+ CompletionCallback callback_;
// In the client callback, the client can do anything, including
// destroying this class, so any pending callback must be issued
// after everything else is done. When it is time to issue the client
- // callback, move it from |user_callback_| to |scheduled_callback_|.
- OldCompletionCallback* scheduled_callback_;
+ // callback, move it from |callback_| to |scheduled_callback_|.
+ CompletionCallback scheduled_callback_;
// The underlying socket.
ClientSocketHandle* const connection_;

Powered by Google App Engine
This is Rietveld 408576698